@@ -74,7 +74,8 @@ func (root *Root) togglePlain(context.Context) {
 	root.setMessagef("Set PlainMode %t", root.Doc.PlainMode)
 }
 
-// togglePlain toggles column rainbow mode.
+// toggleRainbow toggles the column rainbow mode.
+// When enabled, each column will be displayed in a different color for better visual distinction.
 func (root *Root) toggleRainbow(context.Context) {
 	root.Doc.ColumnRainbow = !root.Doc.ColumnRainbow
 	root.setMessagef("Set Column Rainbow Mode %t", root.Doc.ColumnRainbow)
@@ -87,7 +88,7 @@ func (root *Root) toggleFollowMode(context.Context) {
 
 // toggleFollowAll toggles follow all mode.
 func (root *Root) toggleFollowAll(context.Context) {
-	root.General.FollowAll = !root.General.FollowAll
+	root.FollowAll = !root.FollowAll
 	root.mu.Lock()
 	for _, doc := range root.DocList {
 		doc.latestNum = doc.BufEndNum()
@@ -119,14 +120,25 @@ func (root *Root) toggleMouse(context.Context) {
 	}
 }
 
+// toggleStatusLine toggles the status line visibility.
+func (root *Root) toggleStatusLine(context.Context) {
+	root.Doc.StatusLine = !root.Doc.StatusLine
+	if root.Doc.StatusLine {
+		root.setMessage("Status Line visible")
+	} else {
+		root.setMessage("Status Line hidden")
+	}
+}
+
+// toggleRuler cycles through the ruler types (None, Relative, Absolute) each time it is called.
 func (root *Root) toggleRuler(ctx context.Context) {
-	switch root.Doc.general.RulerType {
+	switch root.Doc.RulerType {
 	case RulerNone:
-		root.Doc.general.RulerType = RulerRelative
+		root.Doc.RulerType = RulerRelative
 	case RulerRelative:
-		root.Doc.general.RulerType = RulerAbsolute
+		root.Doc.RulerType = RulerAbsolute
 	case RulerAbsolute:
-		root.Doc.general.RulerType = RulerNone
+		root.Doc.RulerType = RulerNone
 	}
 	root.setMessagef("Set Ruler %s", root.Doc.RulerType.String())
 	root.ViewSync(ctx)
@@ -174,7 +186,7 @@ func (root *Root) watchControl() {
 	if !root.Doc.WatchMode {
 		return
 	}
-	log.Printf("watch start at interval %d", m.WatchInterval)
+	log.Printf("watch start at interval: %d\n", m.WatchInterval)
 	m.ticker = time.NewTicker(time.Duration(m.WatchInterval) * time.Second)
 	atomic.StoreInt32(&m.tickerState, 1)
 	go func() {
@@ -220,31 +232,19 @@ func (root *Root) goLine(input string) {
 	if len(input) == 0 {
 		return
 	}
-	num := calculatePosition(input, root.Doc.BufEndNum())
-	str := strconv.FormatFloat(num, 'f', 1, 64)
-	if strings.HasSuffix(str, ".0") {
-		// Line number only.
-		lN, err := strconv.Atoi(str[:len(str)-2])
-		if err != nil {
-			root.setMessage(ErrInvalidNumber.Error())
-			return
-		}
-		lN = root.Doc.moveLine(lN - 1)
-		root.Doc.showGotoF = true
-		root.setMessagef("Moved to line %d", lN+1)
+	num, err := calculatePosition(input, root.Doc.BufEndNum())
+	if err != nil {
+		root.setMessage(ErrInvalidNumber.Error())
 		return
 	}
 
-	// Line number and number of wrapping lines.
-	inputs := strings.Split(str, ".")
-	lN, err := strconv.Atoi(inputs[0])
-	if err != nil {
-		root.setMessage(ErrInvalidNumber.Error())
-		return
-	}
-	nTh, err := strconv.Atoi(inputs[1])
-	if err != nil {
-		root.setMessage(ErrInvalidNumber.Error())
+	integerPart, fractionalPart := math.Modf(num)
+	lN := int(integerPart)
+	nTh := int(fractionalPart * 10)
+	if nTh == 0 {
+		lN = root.Doc.moveLine(lN - 1)
+		root.Doc.showGotoF = true
+		root.setMessagef("Moved to line %d", lN+1)
 		return
 	}
 	lN, nTh = root.Doc.moveLineNth(lN-1, nTh)
@@ -366,12 +366,13 @@ func (root *Root) setSectionNum(input string) {
 	root.setMessagef("Set section header num %d", num)
 }
 
-func specifyOnScreen(input string, max int) (int, error) {
+// specifyOnScreen checks if the input is a valid number.
+func specifyOnScreen(input string, height int) (int, error) {
 	num, err := strconv.Atoi(input)
 	if err != nil {
 		return 0, ErrInvalidNumber
 	}
-	if num < 0 || num > max {
+	if num < 0 || num > height {
 		return 0, ErrOutOfRange
 	}
 	return num, nil
@@ -418,18 +419,15 @@ func (root *Root) subShell(shell string) error {
 	if shell == "" {
 		shell = getShell()
 	}
-
 	stdin := os.Stdin
-	if !term.IsTerminal(int(os.Stdin.Fd())) {
-		// Use TTY as stdin when the current stdin is not a terminal.
-		tty, err := getTty()
+	if !term.IsTerminal(int(stdin.Fd())) {
+		tty, err := getTTY()
 		if err != nil {
-			return fmt.Errorf("failed to open tty: %w", err)
+			return fmt.Errorf("failed to get stdin: %w", err)
 		}
 		defer tty.Close()
 		stdin = tty
 	}
-
 	c := exec.Command(shell, "-l")
 	c.Stdin = stdin
 	c.Stdout = os.Stdout
@@ -441,64 +439,56 @@ func (root *Root) subShell(shell string) error {
 	return nil
 }
 
-func getShell() string {
-	if runtime.GOOS == "windows" {
-		return "CMD.EXE"
-	}
-	return "/bin/sh"
-}
-
-func getTty() (*os.File, error) {
-	if runtime.GOOS == "windows" {
-		return os.Open("CONIN$")
-	}
-	return os.Open("/dev/tty")
-}
-
 // setViewMode switches to the preset display mode.
-// Set header lines and columnMode together.
 func (root *Root) setViewMode(ctx context.Context, modeName string) {
-	c, err := root.modeConfig(modeName)
+	if modeName == "" {
+		return
+	}
+
+	settings, err := root.modeConfig(modeName)
 	if err != nil {
-		root.setMessage(err.Error())
+		root.setMessageLog(err.Error())
 		return
 	}
 	m := root.Doc
-	m.general = mergeGeneral(m.general, c)
-	m.conv = m.converterType(m.general.Converter)
+	m.RunTimeSettings = settings
+	m.conv = m.converterType(m.Converter)
+	// Set caption.
+	if settings.Caption != "" {
+		m.Caption = settings.Caption
+	}
 	m.regexpCompile()
 	m.ClearCache()
 	root.ViewSync(ctx)
-	// Set caption.
-	if m.general.Caption != "" {
-		m.Caption = m.general.Caption
-	}
-	root.setMessagef("Set mode %s", modeName)
+	root.setMessageLogf("Set mode %s", modeName)
 }
 
 // modeConfig returns the configuration of the specified mode.
-func (root *Root) modeConfig(modeName string) (general, error) {
+func (root *Root) modeConfig(modeName string) (RunTimeSettings, error) {
 	if modeName == nameGeneral {
-		return root.General, nil
+		settings := updateRunTimeSettings(root.Doc.RunTimeSettings, root.Config.General)
+		return settings, nil
 	}
 
-	c, ok := root.Config.Mode[modeName]
+	viewMode, ok := root.Config.Mode[modeName]
 	if !ok {
-		return general{}, fmt.Errorf("%s mode not found", modeName)
+		return RunTimeSettings{}, fmt.Errorf("view mode not found: %s", modeName)
 	}
-	return c, nil
+	settings := updateRunTimeSettings(root.Doc.RunTimeSettings, viewMode)
+	return settings, nil
 }
 
 // setConverter sets the converter type.
 func (root *Root) setConverter(ctx context.Context, name string) {
 	m := root.Doc
-	if m.general.Converter == name {
+	if m.Converter == name {
 		return
 	}
-	m.general.Converter = name
+	m.Converter = name
 	m.conv = m.converterType(name)
 	m.ClearCache()
 	root.ViewSync(ctx)
+	root.setMessagef("Set %s converter", name)
 }
 
 // alignFormat sets converter type to align.
@@ -508,7 +498,6 @@ func (root *Root) alignFormat(ctx context.Context) {
 		return
 	}
 	root.setConverter(ctx, convAlign)
-	root.setMessage("Set align mode")
 }
 
 // rawFormat sets converter type to raw.
@@ -518,13 +507,11 @@ func (root *Root) rawFormat(ctx context.Context) {
 		return
 	}
 	root.setConverter(ctx, convRaw)
-	root.setMessage("Set raw mode")
 }
 
 // esFormat sets converter type to es.
 func (root *Root) esFormat(ctx context.Context) {
 	root.setConverter(ctx, convEscaped)
-	root.setMessage("Set es mode")
 }
 
 // setDelimiter sets the delimiter string.
@@ -580,10 +567,10 @@ func (root *Root) setWriteBA(ctx context.Context, input string) {
 		root.setMessage(ErrInvalidNumber.Error())
 		return
 	}
-	root.BeforeWriteOriginal = before
-	root.AfterWriteOriginal = after
-	root.debugMessage(fmt.Sprintf("Before:After:%d:%d", root.BeforeWriteOriginal, root.AfterWriteOriginal))
-	root.IsWriteOriginal = true
+	root.Config.BeforeWriteOriginal = before
+	root.Config.AfterWriteOriginal = after
+	root.debugMessage(fmt.Sprintf("Before:After:%d:%d", root.Config.BeforeWriteOriginal, root.Config.AfterWriteOriginal))
+	root.Config.IsWriteOnExit = true
 	root.Quit(ctx)
 }
 
@@ -719,8 +706,11 @@ func jumpPosition(str string, height int) (int, bool) {
 	if s[0] == 's' {
 		return 0, true
 	}
-
-	num := int(math.Round(calculatePosition(s, height)))
+	n, err := calculatePosition(s, height)
+	if err != nil {
+		return 0, false
+	}
+	num := int(math.Round(n))
 	if num < 0 {
 		return (height - 1) + num, false
 	}
@@ -730,9 +720,9 @@ func jumpPosition(str string, height int) (int, bool) {
 // CalculatePosition returns the number from the length for positive
 // numbers (1), returns dot.number for percentages (.5) = 50%,
 // and returns the % after the number for percentages (50%). return.
-func calculatePosition(str string, length int) float64 {
+func calculatePosition(str string, length int) (float64, error) {
 	if len(str) == 0 || str == "0" {
-		return 0
+		return 0, nil
 	}
 
 	var p float64 = 0
@@ -740,7 +730,7 @@ func calculatePosition(str string, length int) float64 {
 		str = strings.TrimLeft(str, ".")
 		i, err := strconv.ParseFloat(str, 64)
 		if err != nil {
-			return 0
+			return 0, err
 		}
 		p = i / 10
 	}
@@ -748,20 +738,20 @@ func calculatePosition(str string, length int) float64 {
 		str = strings.TrimRight(str, "%")
 		i, err := strconv.ParseFloat(str, 64)
 		if err != nil {
-			return 0
+			return 0, err
 		}
 		p = i / 100
 	}
 
 	if p > 0 {
-		return float64(length) * p
+		return float64(length) * p, nil
 	}
 
 	num, err := strconv.ParseFloat(str, 64)
 	if err != nil {
-		return 0
+		return 0, err
 	}
-	return num
+	return num, nil
 }
 
 // TailSync move to tail and sync.
@@ -842,34 +832,48 @@ func (root *Root) followSection(ctx context.Context) {
 
 // Cancel follow mode and follow all mode.
 func (root *Root) Cancel(context.Context) {
-	root.General.FollowAll = false
+	root.FollowAll = false
 	root.Doc.FollowMode = false
 }
 
+// toggleWriteOriginal toggles the write flag.
+func (root *Root) toggleWriteOriginal(context.Context) {
+	root.Config.IsWriteOriginal = !root.Config.IsWriteOriginal
+	root.setMessagef("Set WriteOriginal %t", root.Config.IsWriteOriginal)
+}
+
 // WriteQuit sets the write flag and executes a quit event.
 func (root *Root) WriteQuit(ctx context.Context) {
-	root.IsWriteOriginal = true
-	if root.Doc.HideOtherSection && root.AfterWriteOriginal == 0 {
-		// hide other section.
-		root.AfterWriteOriginal = root.bottomSectionLN(ctx)
+	if root.Doc.documentType != DocNormal {
+		log.Println("WriteQuit: not a normal document")
+		root.Quit(ctx)
+		return
 	}
+
+	root.Config.IsWriteOnExit = true
+	if root.Doc.HideOtherSection && root.Config.AfterWriteOriginal == 0 {
+		// hide other section.
+		root.Config.AfterWriteOriginal = root.bottomSectionLN(ctx)
+	}
+	root.OnExit = root.ScreenContent()
+
 	root.Quit(ctx)
 }
 
 // bottomSectionLN returns the number of lines to write.
 func (root *Root) bottomSectionLN(ctx context.Context) int {
 	if root.Doc.SectionDelimiter == "" {
-		return root.AfterWriteOriginal
+		return root.Config.AfterWriteOriginal
 	}
 	lN, err := root.Doc.nextSection(ctx, root.Doc.topLN+root.Doc.firstLine()-root.Doc.SectionStartPosition)
 	if err != nil {
-		return root.AfterWriteOriginal
+		return root.Config.AfterWriteOriginal
 	}
 	return lN - (root.Doc.topLN + root.Doc.firstLine() - root.Doc.SectionStartPosition)
 }
 
 // toggleFixedColumn toggles the fixed column.
-func (root *Root) toggleFixedColumn(ctx context.Context) {
+func (root *Root) toggleFixedColumn(context.Context) {
 	cursor := root.Doc.columnCursor - root.Doc.columnStart + 1
 	if root.Doc.HeaderColumn == cursor {
 		cursor = 0
@@ -880,17 +884,17 @@ func (root *Root) toggleFixedColumn(ctx context.Context) {
 }
 
 // ShrinkColumn shrinks the specified column.
-func (root *Root) ShrinkColumn(ctx context.Context, cursor int) error {
+func (root *Root) ShrinkColumn(_ context.Context, cursor int) error {
 	return root.Doc.shrinkColumn(cursor, true)
 }
 
 // ExpandColumn expands the specified column.
-func (root *Root) ExpandColumn(ctx context.Context, cursor int) error {
+func (root *Root) ExpandColumn(_ context.Context, cursor int) error {
 	return root.Doc.shrinkColumn(cursor, false)
 }
 
 // toggleShrinkColumn shrinks or expands the current cursor column.
-func (root *Root) toggleShrinkColumn(ctx context.Context) {
+func (root *Root) toggleShrinkColumn(_ context.Context) {
 	cursor := root.Doc.columnCursor
 	shrink, err := root.Doc.isColumnShrink(cursor)
 	if err != nil {
@@ -901,7 +905,7 @@ func (root *Root) toggleShrinkColumn(ctx context.Context) {
 	}
 }
 
-// shinkColumn shrinks or expands the specified column.
+// shrinkColumn shrinks or expands the specified column.
 func (m *Document) shrinkColumn(cursor int, shrink bool) error {
 	if err := m.isValidColumn(cursor); err != nil {
 		return err
@@ -920,7 +924,7 @@ func (m *Document) isColumnShrink(cursor int) (bool, error) {
 }
 
 // toggleRightAlign toggles the right align of the current cursor column.
-func (root *Root) toggleRightAlign(ctx context.Context) {
+func (root *Root) toggleRightAlign(_ context.Context) {
 	m := root.Doc
 	align, err := m.toggleRightAlign(m.columnCursor)
 	if err != nil {
