@@ -1,5 +1,9 @@
 package oviewer
 
+import (
+	"time"
+)
+
 // Config represents the settings of ov.
 type Config struct {
 	// KeyBinding
@@ -13,7 +17,7 @@ type Config struct {
 	DefaultKeyBind string
 
 	// Prompt is the prompt setting.
-	Prompt OVPromptConfig
+	Prompt PromptConfig
 	// MinStartX is the minimum value of the start position.
 	MinStartX int
 
@@ -24,6 +28,10 @@ type Config struct {
 
 	// GeneralConfig is the general setting.
 	General General
+	// helpConfig is the help setting.
+	HelpDoc General
+	// LogConfig is the log setting.
+	LogDoc General
 	// BeforeWriteOriginal specifies the number of lines before the current position.
 	// 0 is the top of the current screen
 	BeforeWriteOriginal int
@@ -56,6 +64,9 @@ type Config struct {
 	// NotifyEOF specifies the number of times to notify EOF.
 	NotifyEOF int
 
+	// ReadWaitTime is the time to wait for reading before starting a search.
+	ReadWaitTime time.Duration
+
 	// ClipboardMethod specifies the method to use for copying to the clipboard.
 	// Supported values:
 	// - "OSC52": Uses the OSC52 escape sequence for clipboard operations. This requires terminal support.
@@ -63,6 +74,8 @@ type Config struct {
 	// In fact, all other settings are default except for OSC52. In the future, “auto” will be added.
 	ClipboardMethod string
 
+	// Editor is the editor command to use for editing files.
+	Editor string
 	// ShrinkChar specifies the character to display when the column is shrunk.
 	ShrinkChar string
 	// DisableColumnCycle indicates whether to disable column cycling.
@@ -145,10 +158,38 @@ type General struct {
 	SectionHeader *bool
 	// HideOtherSection is whether to hide other sections.
 	HideOtherSection *bool
+	// StatusLine indicates whether to hide the status line.
+	StatusLine *bool
+	// Prompt is the prompt configuration.
+	Prompt PromptConfig
 	// Style is the style setting.
 	Style StyleConfig
 }
 
+// PromptConfigNormal is the normal prompt setting.
+type PromptConfigNormal struct {
+	// ShowFilename controls whether to display filename.
+	ShowFilename *bool
+	// InvertColor controls whether the text is colored and inverted.
+	InvertColor *bool
+	// ProcessOfCount controls whether to display the progress of the count.
+	ProcessOfCount *bool
+	// CursorType controls the type of cursor to display.
+	CursorType *int
+}
+
+// PromptConfigInput is the input prompt setting.
+type PromptConfigInput struct {
+	CursorType *int
+}
+
+// PromptConfig is the prompt setting.
+type PromptConfig struct {
+	// Normal is the normal prompt setting.
+	Normal PromptConfigNormal
+	Input  PromptConfigInput
+}
+
 // OVPromptConfigNormal is the normal prompt setting.
 type OVPromptConfigNormal struct {
 	// ShowFilename controls whether to display filename.
@@ -157,12 +198,32 @@ type OVPromptConfigNormal struct {
 	InvertColor bool
 	// ProcessOfCount controls whether to display the progress of the count.
 	ProcessOfCount bool
+	// CursorType controls the type of cursor to display.
+	CursorType int
+}
+
+// OVPromptConfigInput is the input prompt setting.
+type OVPromptConfigInput struct {
+	CursorType int
 }
 
 // OVPromptConfig is the prompt setting.
 type OVPromptConfig struct {
 	// Normal is the normal prompt setting.
 	Normal OVPromptConfigNormal
+	Input  OVPromptConfigInput
+}
+
+// NewOVPromptConfig returns the structure of OVPromptConfig with default values.
+func NewOVPromptConfig() OVPromptConfig {
+	return OVPromptConfig{
+		Normal: OVPromptConfigNormal{
+			ShowFilename:   true,
+			InvertColor:    true,
+			ProcessOfCount: true,
+		},
+		Input: OVPromptConfigInput{},
+	}
 }
 
 // NewConfig return the structure of Config with default values.
@@ -170,13 +231,7 @@ func NewConfig() Config {
 	return Config{
 		MemoryLimit:     -1,
 		MemoryLimitFile: 100,
-		Prompt: OVPromptConfig{
-			Normal: OVPromptConfigNormal{
-				ShowFilename:   true,
-				InvertColor:    true,
-				ProcessOfCount: true,
-			},
-		},
+		ReadWaitTime:    1000 * time.Millisecond,
 	}
 }
 
@@ -217,6 +272,10 @@ type StyleConfig struct {
 	// VerticalHeaderBorder is the style that applies to the boundary character of the vertical header.
 	// The boundary character of the vertical header refers to the visual separator that delineates the vertical header from the rest of the content.
 	VerticalHeaderBorder *OVStyle
+	// LeftStatus is the style that applies to the left side of the status line.
+	LeftStatus *OVStyle
+	// RightStatus is the style that applies to the right side of the status line.
+	RightStatus *OVStyle
 }
 
 // deprecatedStyleConfig is the old style setting.
