@@ -58,12 +58,6 @@ func (root *Root) event(ctx context.Context, ev tcell.Event) bool {
 		root.copyToClipboard(ctx)
 	case *eventPaste:
 		root.pasteFromClipboard(ctx)
-	case *eventViewMode:
-		root.setViewMode(ctx, ev.value)
-	case *eventConverter:
-		root.setConverter(ctx, ev.value)
-	case *eventInputSearch:
-		root.firstSearch(ctx, ev.searchType)
 	case *eventSearch:
 		root.forwardSearch(ctx, ev.str, 0)
 	case *eventNextSearch:
@@ -72,40 +66,48 @@ func (root *Root) event(ctx context.Context, ev tcell.Event) bool {
 		root.backSearch(ctx, ev.str, -1)
 	case *eventSearchMove:
 		root.searchGo(ctx, ev.ln, ev.searcher)
-	case *eventGoto:
-		root.goLine(ev.value)
-	case *eventHeader:
-		root.setHeader(ev.value)
-	case *eventSkipLines:
-		root.setSkipLines(ev.value)
+	case *eventReachEOF:
+		root.notifyEOFReached(ev.m)
+
+	// Input confirmation action event.
+	case *eventConverter:
+		root.setConverter(ctx, ev.value)
 	case *eventDelimiter:
 		root.setDelimiter(ev.value)
+	case *eventGoto:
+		root.goLine(ev.value)
+	case *eventHeaderColumn:
+		root.setHeaderColumn(ev.value)
+	case *eventHeader:
+		root.setHeader(ev.value)
+	case *eventJumpTarget:
+		root.setJumpTarget(ev.value)
+	case *eventMultiColor:
+		root.setMultiColor(ev.value)
+	case *eventSaveBuffer:
+		root.saveBuffer(ev.value)
+	case *eventInputSearch:
+		root.firstSearch(ctx, ev.searchType)
+	case *eventSkipLines:
+		root.setSkipLines(ev.value)
 	case *eventTabWidth:
 		root.setTabWidth(ev.value)
-	case *eventWatchInterval:
-		root.setWatchInterval(ev.value)
-	case *eventWriteBA:
-		root.setWriteBA(ctx, ev.value)
 	case *eventSectionDelimiter:
 		root.setSectionDelimiter(ev.value)
 	case *eventSectionStart:
 		root.setSectionStart(ev.value)
-	case *eventMultiColor:
-		root.setMultiColor(ev.value)
-	case *eventJumpTarget:
-		root.setJumpTarget(ev.value)
-	case *eventSaveBuffer:
-		root.saveBuffer(ev.value)
 	case *eventSectionNum:
 		root.setSectionNum(ev.value)
 	case *eventVerticalHeader:
 		root.setVerticalHeader(ev.value)
-	case *eventHeaderColumn:
-		root.setHeaderColumn(ev.value)
-	case *eventReachEOF:
-		root.notifyEOFReached(ev.m)
+	case *eventViewMode:
+		root.setViewMode(ctx, ev.value)
+	case *eventWatchInterval:
+		root.setWatchInterval(ev.value)
+	case *eventWriteBA:
+		root.setWriteBA(ctx, ev.value)
 
-	// tcell events
+	// tcell events.
 	case *tcell.EventResize:
 		root.resize(ctx)
 	case *tcell.EventMouse:
@@ -153,7 +155,7 @@ func (root *Root) everyUpdate(ctx context.Context) {
 	}
 
 	switch {
-	case root.General.FollowAll:
+	case root.FollowAll:
 		root.followAll(ctx)
 	case root.Doc.FollowMode:
 		root.follow(ctx)
@@ -173,6 +175,7 @@ func (root *Root) everyUpdate(ctx context.Context) {
 	if root.quitSmallCountDown > 0 {
 		root.quitSmallCountDown--
 		if root.DocumentLen() == 2 && root.Doc.documentType == DocFilter && root.docSmall() {
+			root.draw(ctx)
 			root.WriteQuit(ctx)
 		}
 	}
@@ -248,7 +251,7 @@ func (root *Root) sendUpdateEndNum() {
 	if !root.hasDocChanged() {
 		return
 	}
-	if !root.Config.Prompt.Normal.ProcessOfCount && !root.Doc.BufEOF() {
+	if !root.Doc.Normal.ProcessOfCount && !root.Doc.BufEOF() {
 		return
 	}
 	ev := &eventUpdateEndNum{}
@@ -316,6 +319,7 @@ type eventCloseAllFilter struct {
 	tcell.EventTime
 }
 
+// CloseAllFilter fires the eventCloseAllFilter event.
 func (root *Root) CloseAllFilter() {
 	root.sendCloseAllFilter()
 }
@@ -361,7 +365,7 @@ func (root *Root) postEvent(ev tcell.Event) {
 	}
 
 	if err := root.Screen.PostEvent(ev); err != nil {
-		log.Printf("postEvent %s", err)
+		log.Printf("postEvent: %v\n", err)
 		root.releaseEventBuffer()
 	}
 }
