@@ -24,7 +24,7 @@ import (
 // Root is the root structure of the oviewer.
 type Root struct {
 	// tcell.Screen is the root screen.
-	tcell.Screen
+	Screen tcell.Screen
 
 	// settings contains the runtime settings template.
 	// These settings serve as the base configuration for each document.
@@ -71,7 +71,7 @@ type Root struct {
 	// scr contains the screen information.
 	scr SCR
 	// Config is the configuration of ov.
-	Config
+	Config Config
 	// Original position at the start of search.
 	OriginPos int
 
@@ -107,6 +107,9 @@ type SCR struct {
 	startX int
 	// startY is the start position of y.
 	startY int
+	// statusLineHeight is the height of the status line.
+	statusLineHeight int
+
 	// rulerHeight is the height of the ruler.
 	rulerHeight int
 	// HeaderLN is the number of header lines.
@@ -243,7 +246,11 @@ type RunTimeSettings struct {
 	SectionHeader bool
 	// HideOtherSection is whether to hide other sections.
 	HideOtherSection bool
+	// StatusLine is whether to hide the status line.
+	StatusLine bool
 
+	// PromptConfig is the prompt configuration.
+	OVPromptConfig
 	// Style is the style of the document.
 	Style Style
 }
@@ -285,6 +292,10 @@ type Style struct {
 	// VerticalHeaderBorder is the style that applies to the boundary character of the vertical header.
 	// The boundary character of the vertical header refers to the visual separator that delineates the vertical header from the rest of the content.
 	VerticalHeaderBorder OVStyle
+	// LeftStatus is the style that applies to the left status line.
+	LeftStatus OVStyle
+	// RightStatus is the style that applies to the right status line.
+	RightStatus OVStyle
 }
 
 var (
@@ -442,7 +453,9 @@ func NewRunTimeSettings() RunTimeSettings {
 		TabWidth:       8,
 		MarkStyleWidth: 1,
 		Converter:      convEscaped,
+		OVPromptConfig: NewOVPromptConfig(),
 		Style:          NewStyle(),
+		StatusLine:     true,
 	}
 }
 
@@ -596,6 +609,8 @@ func openFiles(fileNames []string) (*Root, error) {
 func (root *Root) SetConfig(config Config) {
 	// Old Style* settings are loaded with lower priority.
 	root.settings = setOldStyle(root.settings, config)
+	// Old Prompt settings are loaded with lower priority.
+	root.settings = setOldPrompt(root.settings, config)
 	// General settings.
 	root.settings = updateRunTimeSettings(root.settings, config.General)
 
@@ -732,8 +747,8 @@ func (root *Root) Run() error {
 	}
 
 	// Quit if fits on screen.
-	if root.QuitSmall && root.DocumentLen() == 1 && root.docSmall() {
-		root.IsWriteOnExit = true
+	if root.Config.QuitSmall && root.DocumentLen() == 1 && root.docSmall() {
+		root.Config.IsWriteOnExit = true
 		return nil
 	}
 
@@ -792,9 +807,9 @@ func (root *Root) prepareRun(ctx context.Context) error {
 	root.setViewModeConfig()
 	root.prepareAllDocuments()
 	// Quit by filter result. This is evaluated lazily.
-	if root.QuitSmallFilter {
+	if root.Config.QuitSmallFilter {
 		root.quitSmallCountDown = QuitSmallCountDown
-		root.QuitSmall = false
+		root.Config.QuitSmall = false
 	}
 	root.ViewSync(ctx)
 	return nil
@@ -835,18 +850,19 @@ func (root *Root) prepareAllDocuments() {
 		if doc.ColumnWidth {
 			doc.ColumnMode = true
 		}
-		if doc.RunTimeSettings.Converter != "" {
-			doc.conv = doc.converterType(doc.RunTimeSettings.Converter)
+		if doc.Converter != "" {
+			doc.conv = doc.converterType(doc.Converter)
 		}
 		w := ""
-		if doc.RunTimeSettings.WatchInterval > 0 {
+		if doc.WatchInterval > 0 {
 			doc.watchMode()
 			w = "(watch)"
 		}
 		log.Printf("open [%d]%s%s\n", n, doc.FileName, w)
 	}
-	root.helpDoc.Style = root.settings.Style
-	root.logDoc.Style = root.settings.Style
+
+	root.helpDoc.RunTimeSettings = updateRunTimeSettings(root.helpDoc.RunTimeSettings, root.Config.HelpDoc)
+	root.logDoc.RunTimeSettings = updateRunTimeSettings(root.logDoc.RunTimeSettings, root.Config.LogDoc)
 }
 
 // Close closes the oviewer.
@@ -868,7 +884,7 @@ func (root *Root) setMessage(msg string) {
 	root.message = msg
 	root.debugMessage(msg)
 	root.drawStatus()
-	root.Show()
+	root.Screen.Show()
 }
 
 // setMessageLogf displays a formatted message in the status and outputs it to the log.
@@ -885,12 +901,12 @@ func (root *Root) setMessageLog(msg string) {
 	root.message = msg
 	log.Print(msg)
 	root.drawStatus()
-	root.Show()
+	root.Screen.Show()
 }
 
 // debugMessage outputs a debug message.
 func (root *Root) debugMessage(msg string) {
-	if !root.Debug {
+	if !root.Config.Debug {
 		return
 	}
 	if root.Doc == root.logDoc.Document {
@@ -909,20 +925,67 @@ func (root *Root) debugMessage(msg string) {
 // It reads and applies old style settings to maintain compatibility with older configurations.
 // Use the new style configuration methods instead.
 func setOldStyle(src RunTimeSettings, config Config) RunTimeSettings {
-	src.Style.Body = config.StyleBody
-	src.Style.Header = config.StyleHeader
-	src.Style.LineNumber = config.StyleLineNumber
-	src.Style.SearchHighlight = config.StyleSearchHighlight
-	src.Style.ColumnHighlight = config.StyleColumnHighlight
-	src.Style.MarkLine = config.StyleMarkLine
-	src.Style.SectionLine = config.StyleSectionLine
-	src.Style.VerticalHeader = config.StyleVerticalHeader
-	src.Style.JumpTargetLine = config.StyleJumpTargetLine
-	src.Style.Alternate = config.StyleAlternate
-	src.Style.Ruler = config.StyleRuler
-	src.Style.HeaderBorder = config.StyleHeaderBorder
-	src.Style.SectionHeaderBorder = config.StyleSectionHeaderBorder
-	src.Style.VerticalHeaderBorder = config.StyleVerticalHeaderBorder
+	blank := OVStyle{}
+	if config.StyleBody != blank {
+		src.Style.Body = config.StyleBody
+	}
+	if config.StyleHeader != blank {
+		src.Style.Header = config.StyleHeader
+	}
+	if config.StyleLineNumber != blank {
+		src.Style.LineNumber = config.StyleLineNumber
+	}
+	if config.StyleSearchHighlight != blank {
+		src.Style.SearchHighlight = config.StyleSearchHighlight
+	}
+	if config.StyleColumnHighlight != blank {
+		src.Style.ColumnHighlight = config.StyleColumnHighlight
+	}
+	if config.StyleMarkLine != blank {
+		src.Style.MarkLine = config.StyleMarkLine
+	}
+	if config.StyleSectionLine != blank {
+		src.Style.SectionLine = config.StyleSectionLine
+	}
+	if config.StyleVerticalHeader != blank {
+		src.Style.VerticalHeader = config.StyleVerticalHeader
+	}
+	if config.StyleJumpTargetLine != blank {
+		src.Style.JumpTargetLine = config.StyleJumpTargetLine
+	}
+	if config.StyleAlternate != blank {
+		src.Style.Alternate = config.StyleAlternate
+	}
+	if config.StyleRuler != blank {
+		src.Style.Ruler = config.StyleRuler
+	}
+	if config.StyleHeaderBorder != blank {
+		src.Style.HeaderBorder = config.StyleHeaderBorder
+	}
+	if config.StyleSectionHeaderBorder != blank {
+		src.Style.SectionHeaderBorder = config.StyleSectionHeaderBorder
+	}
+	if config.StyleVerticalHeaderBorder != blank {
+		src.Style.VerticalHeaderBorder = config.StyleVerticalHeaderBorder
+	}
+	return src
+}
+
+// setOldPrompt applies deprecated prompt settings for backward compatibility.
+//
+// Deprecated: This function is planned to be removed in future versions.
+func setOldPrompt(src RunTimeSettings, config Config) RunTimeSettings {
+	prompt := config.Prompt
+	// Old PromptConfig settings are loaded with lower priority.
+	if prompt.Normal.ShowFilename != nil {
+		src.OVPromptConfig.Normal.ShowFilename = *prompt.Normal.ShowFilename
+	}
+	if prompt.Normal.InvertColor != nil {
+		src.OVPromptConfig.Normal.InvertColor = *prompt.Normal.InvertColor
+	}
+	if prompt.Normal.ProcessOfCount != nil {
+		src.OVPromptConfig.Normal.ProcessOfCount = *prompt.Normal.ProcessOfCount
+	}
 	return src
 }
 
@@ -1003,6 +1066,9 @@ func updateRunTimeSettings(src RunTimeSettings, dst General) RunTimeSettings {
 	if dst.HideOtherSection != nil {
 		src.HideOtherSection = *dst.HideOtherSection
 	}
+	if dst.StatusLine != nil {
+		src.StatusLine = *dst.StatusLine
+	}
 	if dst.ColumnDelimiter != nil {
 		src.ColumnDelimiter = *dst.ColumnDelimiter
 	}
@@ -1027,10 +1093,31 @@ func updateRunTimeSettings(src RunTimeSettings, dst General) RunTimeSettings {
 	if dst.Raw != nil && *dst.Raw {
 		src.Converter = convRaw
 	}
+	src.OVPromptConfig = updatePromptConfig(src.OVPromptConfig, dst.Prompt)
 	src.Style = updateRuntimeStyle(src.Style, dst.Style)
 	return src
 }
 
+// updatePromptConfig updates the prompt configuration.
+func updatePromptConfig(src OVPromptConfig, dst PromptConfig) OVPromptConfig {
+	if dst.Normal.InvertColor != nil {
+		src.Normal.InvertColor = *dst.Normal.InvertColor
+	}
+	if dst.Normal.ShowFilename != nil {
+		src.Normal.ShowFilename = *dst.Normal.ShowFilename
+	}
+	if dst.Normal.ProcessOfCount != nil {
+		src.Normal.ProcessOfCount = *dst.Normal.ProcessOfCount
+	}
+	if dst.Normal.CursorType != nil {
+		src.Normal.CursorType = *dst.Normal.CursorType
+	}
+	if dst.Input.CursorType != nil {
+		src.Input.CursorType = *dst.Input.CursorType
+	}
+	return src
+}
+
 // updateRuntimeStyle updates the style.
 func updateRuntimeStyle(src Style, dst StyleConfig) Style {
 	if dst.ColumnRainbow != nil {
@@ -1081,6 +1168,12 @@ func updateRuntimeStyle(src Style, dst StyleConfig) Style {
 	if dst.VerticalHeaderBorder != nil {
 		src.VerticalHeaderBorder = *dst.VerticalHeaderBorder
 	}
+	if dst.LeftStatus != nil {
+		src.LeftStatus = *dst.LeftStatus
+	}
+	if dst.RightStatus != nil {
+		src.RightStatus = *dst.RightStatus
+	}
 	return src
 }
 
@@ -1092,7 +1185,7 @@ func (root *Root) docSmall() bool {
 		return false
 	}
 	height := 0
-	for y := 0; y < m.BufEndNum(); y++ {
+	for y := range m.BufEndNum() {
 		lc, err := m.contents(y)
 		if err != nil {
 			log.Printf("docSmall %d: %v\n", y, err)
@@ -1126,14 +1219,14 @@ func (root *Root) WriteCurrentScreen() {
 
 // outputOnExit outputs to the terminal when exiting.
 func (root *Root) outputOnExit(output io.Writer) {
-	if root.IsWriteOnExit {
-		if root.IsWriteOriginal {
+	if root.Config.IsWriteOnExit {
+		if root.Config.IsWriteOriginal {
 			root.writeOriginal(output)
 		} else {
 			root.writeCurrentScreen(output)
 		}
 	}
-	if root.Debug {
+	if root.Config.Debug {
 		root.writeLog(output)
 	}
 }
@@ -1147,7 +1240,8 @@ func (root *Root) writeCurrentScreen(output io.Writer) {
 			log.Println(err)
 			return
 		}
-		strs = tcellansi.ScreenContentToStrings(root.Screen, 0, root.Doc.width, 0, height-1)
+		strs = tcellansi.ScreenContentToStrings(root.Screen, 0, root.Doc.width, 0, height-root.scr.statusLineHeight)
+		strs = tcellansi.TrimRightSpaces(strs)
 	}
 	for _, str := range strs {
 		if _, err := output.Write([]byte(str)); err != nil {
@@ -1164,11 +1258,11 @@ func (root *Root) dummyScreen() (int, error) {
 		return 0, err
 	}
 	height := root.scr.vHeight
-	if root.BeforeWriteOriginal != 0 || root.AfterWriteOriginal != 0 {
-		root.Doc.topLN = max(root.Doc.topLN+root.Doc.firstLine()-root.BeforeWriteOriginal, 0)
+	if root.Config.BeforeWriteOriginal != 0 || root.Config.AfterWriteOriginal != 0 {
+		root.Doc.topLN = max(root.Doc.topLN+root.Doc.firstLine()-root.Config.BeforeWriteOriginal, 0)
 		end := root.Doc.bottomLN
-		if root.AfterWriteOriginal != 0 {
-			end = root.Doc.topLN + root.AfterWriteOriginal
+		if root.Config.AfterWriteOriginal != 0 {
+			end = root.Doc.topLN + root.Config.AfterWriteOriginal
 		}
 		height = end - root.Doc.topLN
 	}
@@ -1186,7 +1280,7 @@ func (root *Root) dummyScreen() (int, error) {
 
 func realHeight(scr SCR) int {
 	height := 0
-	for ; height < scr.vHeight-1; height++ {
+	for ; height < scr.vHeight-scr.statusLineHeight; height++ {
 		if !scr.lines[scr.numbers[height].number].valid {
 			break
 		}
@@ -1199,7 +1293,9 @@ func (root *Root) ScreenContent() []string {
 	root.Screen.Sync()
 	m := root.Doc
 	height := realHeight(root.scr)
-	return tcellansi.ScreenContentToStrings(root.Screen, 0, m.width, 0, height)
+	strs := tcellansi.ScreenContentToStrings(root.Screen, 0, m.width, 0, height)
+	strs = tcellansi.TrimRightSpaces(strs)
+	return strs
 }
 
 // writeOriginal writes to the original terminal.
@@ -1229,10 +1325,10 @@ func (root *Root) writeOriginal(output io.Writer) {
 		secAdd = m.SectionHeaderNum
 	}
 	// body
-	start := max(m.topLN+m.firstLine()+secAdd, root.scr.sectionHeaderEnd) - root.BeforeWriteOriginal
+	start := max(m.topLN+m.firstLine()+secAdd, root.scr.sectionHeaderEnd) - root.Config.BeforeWriteOriginal
 	end := m.bottomLN - 1
-	if root.AfterWriteOriginal != 0 {
-		end = m.topLN + root.AfterWriteOriginal - 1
+	if root.Config.AfterWriteOriginal != 0 {
+		end = m.topLN + root.Config.AfterWriteOriginal - 1
 	}
 	if err := m.Export(output, start, end); err != nil {
 		log.Println(err)
@@ -1266,11 +1362,11 @@ func (scr SCR) lineNumber(y int) LineNumber {
 
 // debugNumOfChunk outputs the number of chunks.
 func (root *Root) debugNumOfChunk() {
-	if !root.Debug {
+	if !root.Config.Debug {
 		return
 	}
-	log.Println("MemoryLimit:", root.MemoryLimit)
-	log.Println("MemoryLimitFile:", root.MemoryLimitFile)
+	log.Println("MemoryLimit:", root.Config.MemoryLimit)
+	log.Println("MemoryLimitFile:", root.Config.MemoryLimitFile)
 	for _, doc := range root.DocList {
 		if !doc.seekable {
 			if MemoryLimit > 0 {
