@@ -8,7 +8,7 @@ import (
 	"strings"
 	"testing"
 
-	"code.rocketnine.space/tslocum/cbind"
+	"codeberg.org/tslocum/cbind"
 	"github.com/gdamore/tcell/v2"
 )
 
